summaryrefslogtreecommitdiffstats
path: root/c/src/tests/psxtests/psxmount/test.c
diff options
context:
space:
mode:
authorJoel Sherrill <joel.sherrill@OARcorp.com>1999-07-01 22:08:13 +0000
committerJoel Sherrill <joel.sherrill@OARcorp.com>1999-07-01 22:08:13 +0000
commitdbf969e1d5f0a394a6c74d1b288847481317db00 (patch)
tree15ea106e5c4e40a22e6b83bcdd280ef6a1812824 /c/src/tests/psxtests/psxmount/test.c
parentCleaned up to behave properly -- does not make a directory in the (diff)
downloadrtems-dbf969e1d5f0a394a6c74d1b288847481317db00.tar.bz2
Test modified to reflect change in calling sequence of mount().
Diffstat (limited to 'c/src/tests/psxtests/psxmount/test.c')
-rw-r--r--c/src/tests/psxtests/psxmount/test.c20
1 files changed, 10 insertions, 10 deletions
diff --git a/c/src/tests/psxtests/psxmount/test.c b/c/src/tests/psxtests/psxmount/test.c
index a2a249a35d..4a0e40ffd9 100644
--- a/c/src/tests/psxtests/psxmount/test.c
+++ b/c/src/tests/psxtests/psxmount/test.c
@@ -156,7 +156,7 @@ int main(
status = mount(
&mt_entry,
&IMFS_ops,
- "RW",
+ RTEMS_FILESYSTEM_READ_WRITE,
NULL,
mount_point_string );
assert( status == 0 );
@@ -217,21 +217,21 @@ int main(
status = mount(
&mt_entry,
NULL,
- "RW",
+ RTEMS_FILESYSTEM_READ_WRITE,
NULL,
mount_point_string );
assert( status == -1 );
assert( errno == EINVAL );
/*
* Verify mount with option RA fails with EINVAL
*/
- printf("mount with option RA should fail with EINVAL\n");
+ printf("mount with option of -62 should fail with EINVAL\n");
status = mount(
&mt_entry,
&IMFS_ops,
- "RA",
+ -62,
NULL,
"/c/y/my_mount_point" );
assert( status == -1 );
@@ -245,7 +245,7 @@ int main(
status = mount(
&mt_entry,
&IMFS_ops,
- "RO",
+ RTEMS_FILESYSTEM_READ_ONLY,
NULL,
"/c/y/my_mount_point" );
assert( status == 0 );
@@ -276,7 +276,7 @@ int main(
status = mount(
&mt_entry,
&IMFS_ops,
- "RO",
+ RTEMS_FILESYSTEM_READ_ONLY,
NULL,
"/c/y/my_mount_point" );
assert( status == -1 );
@@ -290,7 +290,7 @@ int main(
status = mount(
&mt_entry,
&IMFS_ops,
- "RO",
+ RTEMS_FILESYSTEM_READ_ONLY,
NULL,
"/b/my_file" );
assert( status == -1 );
@@ -342,7 +342,7 @@ int main(
status = mount(
&mt_entry,
&IMFS_ops,
- "RO",
+ RTEMS_FILESYSTEM_READ_ONLY,
NULL,
"/c/y/my_mount_point" );
assert( status == 0 );
@@ -391,7 +391,7 @@ int main(
status = mount(
&mt_entry,
&IMFS_ops,
- "RW",
+ RTEMS_FILESYSTEM_READ_WRITE,
NULL,
"/c/y/my_mount_point/my_dir");
assert( status == 0 );
@@ -217,21 +217,21 @@ int main(
assert( errno == EINVAL );
/*
- * Verify mount with option RA fails with EINVAL
+ * Verify mount with option of -62 fails with EINVAL
*/